import { Feature, FeatureWithRouterFactory } from '@common-stack/client-react';
import { interfaces } from 'inversify';
import LayoutModule from '@workbench-stack/layout';
import ModalModule from '@workbench-stack/modal';
import { ThemeModule } from '@workbench-stack/components';
import SettingsModule from '@workbench-stack/settings';
import OutputModule from '@workbench-stack/output-browser';
import { resolvers, schema } from './graphql';
import { workbenchModule } from './containers';
import { IEditorService, ClientTypes, IModelService, IClientService } from '@workbench-stack/core';

const workbenchServiceGen = (container: interfaces.Container): IClientService => {
  return {
    editorService: container.get<IEditorService>(ClientTypes.IEditorService),
    modelService: container.get<IModelService>(ClientTypes.IModelService),
  };
};


export default new Feature(
  FeatureWithRouterFactory,
  LayoutModule, ThemeModule,
  ModalModule, SettingsModule,
  OutputModule,
  new Feature({
    clientStateParams: [{ resolvers, typeDefs: schema }],
    createContainerFunc: workbenchModule,
    createServiceFunc: workbenchServiceGen,
  }),
);
